@@ -4,9 +4,6 @@ kombu.compression
 
 Object utilities.
 
-:copyright: (c) 2009 - 2012 by Ask Solem.
-:license: BSD, see LICENSE for more details.
-
 """
 from __future__ import absolute_import
 
@@ -14,6 +11,7 @@ from copy import copy
 
 from .connection import maybe_channel
 from .exceptions import NotBoundError
+from .utils import ChannelPromise
 
 __all__ = ['Object', 'MaybeChannelBound']
 
@@ -39,11 +37,6 @@ class Object(object):
                 except AttributeError:
                     setattr(self, name, None)
 
-    def setdefault(self, **defaults):
-        for key, value in defaults.iteritems():
-            if getattr(self, key) is None:
-                setattr(self, key, value)
-
     def as_dict(self, recurse=False):
         def f(obj):
             if recurse and isinstance(obj, Object):
@@ -110,8 +103,11 @@ class MaybeChannelBound(Object):
     @property
     def channel(self):
         """Current channel if the object is bound."""
-        if self._channel is None:
+        channel = self._channel
+        if channel is None:
             raise NotBoundError(
                 "Can't call method on %s not bound to a channel" % (
                     self.__class__.__name__))
-        return self._channel
+        if isinstance(channel, ChannelPromise):
+            channel = self._channel = channel()
+        return channel
