@@ -4,9 +4,6 @@ kombu.entity
 
 Exchange and Queue declarations.
 
-:copyright: (c) 2009 - 2012 by Ask Solem.
-:license: BSD, see LICENSE for more details.
-
 """
 from __future__ import absolute_import
 
@@ -157,6 +154,33 @@ class Exchange(MaybeChannelBound):
                                              nowait=nowait,
                                              passive=passive)
 
+    def bind_to(self, exchange='', routing_key='',
+                arguments=None, nowait=False, **kwargs):
+        """Binds the exchange to another exchange.
+
+        :keyword nowait: If set the server will not respond, and the call
+            will not block waiting for a response.  Default is :const:`False`.
+
+        """
+        if isinstance(exchange, Exchange):
+            exchange = exchange.name
+        return self.channel.exchange_bind(destination=self.name,
+                                          source=exchange,
+                                          routing_key=routing_key,
+                                          nowait=nowait,
+                                          arguments=arguments)
+
+    def unbind_from(self, source='', routing_key='', nowait=False,
+            arguments=None):
+        """Delete previously created exchange binding from the server."""
+        if isinstance(source, Exchange):
+            source = source.name
+        return self.channel.exchange_unbind(destination=self.name,
+                                            source=source,
+                                            routing_key=routing_key,
+                                            nowait=nowait,
+                                            arguments=arguments)
+
     def Message(self, body, delivery_mode=None, priority=None,
             content_type=None, content_encoding=None, properties=None,
             headers=None):
@@ -249,6 +273,47 @@ class Exchange(MaybeChannelBound):
         return self.durable
 
 
+class binding(object):
+    """Represents a queue or exchange binding.
+
+    :keyword exchange: Exchange to bind to.
+    :keyword routing_key: Routing key used as binding key.
+    :keyword arguments: Arguments for bind operation.
+    :keyword unbind_arguments: Arguments for unbind operation.
+
+    """
+
+    def __init__(self, exchange=None, routing_key='', arguments=None,
+            unbind_arguments=None):
+        self.exchange = exchange
+        self.routing_key = routing_key
+        self.arguments = arguments
+        self.unbind_arguments = unbind_arguments
+
+    def declare(self, channel, nowait=False):
+        """Declare destination exchange."""
+        if self.exchange and self.exchange.name:
+            ex = self.exchange(channel)
+            ex.declare(nowait=nowait)
+
+    def bind(self, entity, nowait=False):
+        """Bind entity to this binding."""
+        entity.bind_to(exchange=self.exchange,
+                       routing_key=self.routing_key,
+                       arguments=self.arguments,
+                       nowait=nowait)
+
+    def unbind(self, entity, nowait=False):
+        """Unbind entity from this binding."""
+        entity.unbind_from(self.exchange,
+                           routing_key=self.routing_key,
+                           arguments=self.unbind_arguments,
+                           nowait=nowait)
+
+    def __repr__(self):
+        return '<binding: %r -> %r>' % (self.exchange.name, self.routing_key)
+
+
 class Queue(MaybeChannelBound):
     """A Queue declaration.
 
@@ -361,14 +426,23 @@ class Queue(MaybeChannelBound):
              ('exclusive', bool),
              ('auto_delete', bool),
              ('no_ack', None),
-             ('alias', None))
+             ('alias', None),
+             ('bindings', None))
 
     def __init__(self, name='', exchange=None, routing_key='', channel=None,
-            **kwargs):
+            bindings=None, **kwargs):
         super(Queue, self).__init__(**kwargs)
         self.name = name or self.name
         self.exchange = exchange or self.exchange
         self.routing_key = routing_key or self.routing_key
+        self.bindings = set(bindings or [])
+
+        # allows Queue('name', [binding(...), binding(...), ...])
+        if isinstance(exchange, (list, tuple, set)):
+            self.bindings |= set(exchange)
+        if self.bindings:
+            self.exchange = None
+
         # exclusive implies auto-delete.
         if self.exclusive:
             self.auto_delete = True
@@ -384,13 +458,18 @@ class Queue(MaybeChannelBound):
     def declare(self, nowait=False):
         """Declares the queue, the exchange and binds the queue to
         the exchange."""
+        # - declare main binding.
         if self.exchange:
             self.exchange.declare(nowait)
         self.queue_declare(nowait, passive=False)
-        # self.name should be set by queue_declare in the case that
-        # we're working with anonymous queues
-        if self.name:
+
+        if self.exchange is not None:
             self.queue_bind(nowait)
+
+        # - declare extra/multi-bindings.
+        for B in self.bindings:
+            B.declare(self.channel)
+            B.bind(self, nowait=nowait)
         return self.name
 
     def queue_declare(self, nowait=False, passive=False):
@@ -415,10 +494,17 @@ class Queue(MaybeChannelBound):
 
     def queue_bind(self, nowait=False):
         """Create the queue binding on the server."""
+        return self.bind_to(self.exchange, self.routing_key,
+                            self.binding_arguments, nowait=nowait)
+
+    def bind_to(self, exchange='', routing_key='', arguments=None,
+            nowait=False):
+        if isinstance(exchange, Exchange):
+            exchange = exchange.name
         return self.channel.queue_bind(queue=self.name,
-                                       exchange=self.exchange.name,
-                                       routing_key=self.routing_key,
-                                       arguments=self.binding_arguments,
+                                       exchange=exchange,
+                                       routing_key=routing_key,
+                                       arguments=arguments,
                                        nowait=nowait)
 
     def get(self, no_ack=None):
@@ -499,12 +585,18 @@ class Queue(MaybeChannelBound):
                                          if_empty=if_empty,
                                          nowait=nowait)
 
-    def unbind(self):
-        """Delete the binding on the server."""
+    def queue_unbind(self, arguments=None, nowait=False):
+        return self.unbind_from(self.exchange, self.routing_key,
+                                arguments, nowait)
+
+    def unbind_from(self, exchange='', routing_key='', arguments=None,
+            nowait=False):
+        """Unbind queue by deleting the binding from the server."""
         return self.channel.queue_unbind(queue=self.name,
-                                         exchange=self.exchange.name,
-                                         routing_key=self.routing_key,
-                                         arguments=self.binding_arguments)
+                                         exchange=exchange.name,
+                                         routing_key=routing_key,
+                                         arguments=arguments,
+                                         nowait=nowait)
 
     def __eq__(self, other):
         if isinstance(other, Queue):
@@ -551,6 +643,7 @@ class Queue(MaybeChannelBound):
         e_arguments = options.get('exchange_arguments')
         q_arguments = options.get('queue_arguments')
         b_arguments = options.get('binding_arguments')
+        bindings = options.get('bindings')
 
         exchange = Exchange(options.get('exchange'),
                             type=options.get('exchange_type'),
@@ -567,4 +660,5 @@ class Queue(MaybeChannelBound):
                      auto_delete=q_auto_delete,
                      no_ack=options.get('no_ack'),
                      queue_arguments=q_arguments,
-                     binding_arguments=b_arguments)
+                     binding_arguments=b_arguments,
+                     bindings=bindings)
