@@ -4,9 +4,6 @@ kombu.pools
 
 Public resource pools.
 
-:copyright: (c) 2009 - 2012 by Ask Solem.
-:license: BSD, see LICENSE for more details.
-
 """
 from __future__ import absolute_import
 
@@ -60,18 +57,18 @@ class ProducerPool(Resource):
     def prepare(self, p):
         if callable(p):
             p = p()
-        if not p.channel:
+        if p._channel is None:
             conn = self._acquire_connection()
             try:
-                p.revive(conn.default_channel)
+                p.revive(conn)
             except BaseException:
                 conn.release()
                 raise
         return p
 
     def release(self, resource):
-        if resource.connection:
-            resource.connection.release()
+        if resource.__connection__:
+            resource.__connection__.release()
         resource.channel = None
         super(ProducerPool, self).release(resource)
 
