@@ -16,7 +16,7 @@ import socket
 from anyjson import loads, dumps
 from Queue import Empty
 
-from kombu.exceptions import StdChannelError
+from kombu.exceptions import StdConnectionError, StdChannelError
 
 from . import virtual
 
@@ -128,7 +128,8 @@ class Transport(virtual.Transport):
 
     polling_interval = 1
     default_port = DEFAULT_PORT
-    connection_errors = (socket.error,
+    connection_errors = (StdConnectionError,
+                         socket.error,
                          beanstalkc.SocketError,
                          IOError)
     channel_errors = (StdChannelError,
