@@ -4,9 +4,6 @@ kombu.transport.redis
 
 Redis transport.
 
-:copyright: (c) 2009 - 2012 by Ask Solem.
-:license: BSD, see LICENSE for more details.
-
 """
 from __future__ import absolute_import
 from __future__ import with_statement
@@ -20,6 +17,7 @@ from anyjson import loads, dumps
 
 from kombu.exceptions import (
     InconsistencyError,
+    StdConnectionError,
     StdChannelError,
     VersionMismatch,
 )
@@ -739,10 +737,10 @@ class Transport(virtual.Transport):
             DataError = exceptions.InvalidData
         else:
             DataError = exceptions.DataError
-        return ((exceptions.ConnectionError,
+        return ((StdConnectionError,
+                 exceptions.ConnectionError,
                  exceptions.AuthenticationError),
-                (exceptions.ConnectionError,
-                 DataError,
+                (DataError,
                  exceptions.InvalidResponse,
                  exceptions.ResponseError,
                  StdChannelError))
