@@ -4,9 +4,6 @@ kombu.utils.debug
 
 Debugging support.
 
-:copyright: (c) 2009 - 2012 by Ask Solem.
-:license: BSD, see LICENSE for more details.
-
 """
 from __future__ import absolute_import
 
@@ -16,11 +13,11 @@ from functools import wraps
 
 from kombu.log import get_logger
 
-__all__ = ["setup_logging", "Logwrapped"]
+__all__ = ['setup_logging', 'Logwrapped']
 
 
-def setup_logging(loglevel=logging.DEBUG, loggers=["kombu.connection",
-                                                   "kombu.channel"]):
+def setup_logging(loglevel=logging.DEBUG, loggers=['kombu.connection',
+                                                   'kombu.channel']):
     for logger in loggers:
         l = get_logger(logger)
         l.addHandler(logging.StreamHandler())
@@ -28,7 +25,7 @@ def setup_logging(loglevel=logging.DEBUG, loggers=["kombu.connection",
 
 
 class Logwrapped(object):
-    __ignore = ("__enter__", "__exit__")
+    __ignore = ('__enter__', '__exit__')
 
     def __init__(self, instance, logger=None, ident=None):
         self.instance = instance
@@ -43,18 +40,18 @@ class Logwrapped(object):
 
         @wraps(meth)
         def __wrapped(*args, **kwargs):
-            info = ""
+            info = ''
             if self.ident:
                 info += self.ident % vars(self.instance)
-            info += "%s(" % (meth.__name__, )
+            info += '%s(' % (meth.__name__, )
             if args:
-                info += ", ".join(map(repr, args))
+                info += ', '.join(map(repr, args))
             if kwargs:
                 if args:
-                    info += ", "
-                info += ", ".join("%s=%r" % (key, value)
+                    info += ', '
+                info += ', '.join('%s=%r' % (key, value)
                                     for key, value in kwargs.iteritems())
-            info += ")"
+            info += ')'
             self.logger.debug(info)
             return meth(*args, **kwargs)
 
