@@ -7,9 +7,6 @@ Utilities to encode text, and to safely emit text from running
 applications without crashing with the infamous :exc:`UnicodeDecodeError`
 exception.
 
-:copyright: (c) 2009 - 2012 by Ask Solem.
-:license: BSD, see LICENSE for more details.
-
 """
 from __future__ import absolute_import
 
@@ -18,10 +15,10 @@ import traceback
 
 is_py3k = sys.version_info >= (3, 0)
 
-if sys.platform.startswith("java"):  # pragma: no cover
+if sys.platform.startswith('java'):  # pragma: no cover
 
     def default_encoding():
-        return "utf-8"
+        return 'utf-8'
 else:
 
     def default_encoding():       # noqa
@@ -51,7 +48,6 @@ if is_py3k:  # pragma: no cover
         return obj
 
     str_t = str
-    bytes_t = bytes
 
 else:
 
@@ -64,43 +60,48 @@ else:
         return s
 
     def from_utf8(s, *args, **kwargs):  # noqa
-        return s.encode("utf-8", *args, **kwargs)
+        return s.encode('utf-8', *args, **kwargs)
 
     def default_encode(obj):            # noqa
         return unicode(obj, default_encoding())
 
     str_t = unicode
-    bytes_t = str
     ensure_bytes = str_to_bytes
 
 
-def safe_str(s, errors="replace"):
+try:
+    bytes_t = bytes
+except NameError:
+    bytes_t = str  # noqa
+
+
+def safe_str(s, errors='replace'):
     s = bytes_to_str(s)
     if not isinstance(s, basestring):
         return safe_repr(s, errors)
     return _safe_str(s, errors)
 
 
-def _safe_str(s, errors="replace"):
+def _safe_str(s, errors='replace'):
     if is_py3k:  # pragma: no cover
         if isinstance(s, str):
             return s
         try:
             return str(s)
         except Exception, exc:
-            return "<Unrepresentable %r: %r %r>" % (
-                    type(s), exc, "\n".join(traceback.format_stack()))
+            return '<Unrepresentable %r: %r %r>' % (
+                    type(s), exc, '\n'.join(traceback.format_stack()))
     encoding = default_encoding()
     try:
         if isinstance(s, unicode):
             return s.encode(encoding, errors)
         return unicode(s, encoding, errors)
     except Exception, exc:
-        return "<Unrepresentable %r: %r %r>" % (
-                type(s), exc, "\n".join(traceback.format_stack()))
+        return '<Unrepresentable %r: %r %r>' % (
+                type(s), exc, '\n'.join(traceback.format_stack()))
 
 
-def safe_repr(o, errors="replace"):
+def safe_repr(o, errors='replace'):
     try:
         return repr(o)
     except Exception:
